@@ -4,7 +4,7 @@
 //
 // started November 2000
 // (c) Peter Beerli Tallahassee 2000-2006
-// $Id: bayes.h 1052 2007-12-03 03:44:31Z beerli $
+// $Id: bayes.h 1124 2008-01-22 16:28:19Z beerli $
 //
 #include "migration.h"
 extern boolean acceptBayes (MYREAL newval, MYREAL oldval);
@@ -23,7 +23,7 @@ extern void bayes_check_and_fix_param(world_fmt *world, option_fmt *options);
 extern void print_bayes_mdimfileheader(FILE *file, long interval, world_fmt *world);
 extern void bayes_print_accept(FILE * outfile, world_fmt * world);
 extern MYREAL probg_treetimes(world_fmt *world);
-extern void recalc_timelist (world_fmt * world, MYREAL new_old_ratio);
+extern void recalc_timelist (world_fmt * world, MYREAL new_ratio, MYREAL old_ratio);
 extern void bayes_smooth(MYREAL *x, long xelem, long el);
 extern void bayes_set_param(MYREAL *param, MYREAL newparam, long which, char *custm2, long numpop);
 extern MYREAL log_prior_ratio_uni(MYREAL newparam, 
