@@ -19,7 +19,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
- $Id: broyden.c 753 2007-06-15 18:17:57Z beerli $
+ $Id: broyden.c 920 2007-09-25 17:13:42Z beerli $
 -------------------------------------------------------*/
 /*! \file broyden.c
 Basic routines for maximum likelihood parameter estimation.
@@ -429,7 +429,7 @@ create_nr (nr_fmt * nr, world_fmt * world, long G,
         if (nr->param[i] > 0.0)
             nr->lparam[i] = LOG (nr->param[i]);
         else
-            nr->lparam[i] = -DBL_MAX;
+            nr->lparam[i] = -MYREAL_MAX;
     }
     // allocate earlier in world: alloc_apg (&nr->apg0, world->repstop, world->loci, G);
     // allicate earlier in world:  alloc_apg (&nr->apg, world->repstop, world->loci, G);
@@ -482,7 +482,7 @@ reuse_nr (nr_fmt * nr, world_fmt * world, long G, long profilenum,
         if (nr->param[i] > 0.0)
             nr->lparam[i] = LOG (nr->param[i]);
         else
-            nr->lparam[i] = -DBL_MAX;
+            nr->lparam[i] = -MYREAL_MAX;
     }
     nr->datalike = (MYREAL *) myrealloc (nr->datalike, (G+1) * sizeof (MYREAL));
     memset (nr->datalike, 0, G * sizeof (MYREAL));
@@ -544,7 +544,7 @@ calc_locus_like (nr_fmt * nr, MYREAL *param, MYREAL *lparam, long locus)
     int stop = (int) (numpop2 + numpop + numpop);
     MYREAL gsum = 0;
     MYREAL ***apg0;
-    MYREAL apgmax = -DBL_MAX;
+    MYREAL apgmax = -MYREAL_MAX;
     //  MYREAL ***apgall = nr->apg;
     MYREAL *apg;
     MYREAL *apg0r;
@@ -632,7 +632,7 @@ calc_locus_like (nr_fmt * nr, MYREAL *param, MYREAL *lparam, long locus)
 
         }
         else
-            apg[0] = -DBL_MAX;
+            apg[0] = -MYREAL_MAX;
         if (apgmax < apg[0])
             apgmax = apg[0];
         //other elements
@@ -661,7 +661,7 @@ calc_locus_like (nr_fmt * nr, MYREAL *param, MYREAL *lparam, long locus)
     for (r = nr->repstart; r < nr->repstop; r++)
     {
         apg = nr->apg[r][locus];
-        apg0r = apg0[r][locus];
+        //apg0r = apg0[r][locus];
         tyme = nr->atl[r][locus];
         // first element
         tl = &(tyme.tl[0]);
@@ -692,7 +692,7 @@ calc_locus_like (nr_fmt * nr, MYREAL *param, MYREAL *lparam, long locus)
     int msta, msto;
     MYREAL gsum = 0;
     MYREAL ***apg0;
-    MYREAL apgmax = -DBL_MAX;
+    MYREAL apgmax = -MYREAL_MAX;
     //  MYREAL ***apgall = nr->apg;
     MYREAL *apg;
     MYREAL *apg0r;
@@ -755,7 +755,7 @@ calc_locus_like (nr_fmt * nr, MYREAL *param, MYREAL *lparam, long locus)
             apg[0] = tl->lcopies + vdot_product (vlocal, tl->vdata, size) - apg0r[0] + normaldev;
         }
         else
-            apg[0] = -DBL_MAX;
+            apg[0] = -MYREAL_MAX;
         if (apgmax < apg[0])
             apgmax = apg[0];
         //other elements
@@ -807,7 +807,7 @@ ln_copies (long n)
     switch (n)
     {
     case 0:
-        return -DBL_MAX;
+        return -MYREAL_MAX;
     case 1:
         return 0.;
     case 2:
@@ -952,7 +952,7 @@ param_all_adjust (MYREAL *xv, nr_fmt *nr)
         force_samemigration (param, wopt, numpop);
     
 	for (i = 0; i < zeron; i++)
-        param[zeros[i]] = -30.; //-DBL_MAX;
+        param[zeros[i]] = -30.; //-MYREAL_MAX;
     
 	for (i = 0; i < constn; i++)
     {
@@ -1131,7 +1131,7 @@ check_matrix_arbitrary (MYREAL *param, worldoption_fmt * wopt, long numpop, long
         force_samemigration (param, wopt, numpop);
     for (i = 0; i < zeron; i++)
     {
-        param[zeros[i]] = -30.; //-DBL_MAX;
+        param[zeros[i]] = -30.; //-MYREAL_MAX;
     }
 
     for (i = 0; i < constn; i++)
@@ -1705,8 +1705,8 @@ probG (MYREAL *param, MYREAL *lparam, tarchive_fmt * tl, nr_fmt * nr,
     MYREAL lmu_rate = nr->world->options->lmu_rates[locus];
     for (i = 0; i < numpop; i++)
     {
-        if (lparam[i] <= -DBL_MAX)
-            return DBL_MAX;
+        if (lparam[i] <= -MYREAL_MAX)
+            return MYREAL_MAX;
         result += tl->p[i] * (LOG2 - (lparam[i] + lmu_rate));
         msta = nr->mstart[i];
         msto = nr->mend[i];
@@ -1870,7 +1870,7 @@ probG4_longsum (MYREAL *fullparam, longsum_fmt *data, long longsumlen, long nump
             result +=  fullparam[tint->to] - rawlrates[ptime] ;
             break;
         case 'm':
-            if (fullparam[tint->fromto] > -DBL_MAX)
+            if (fullparam[tint->fromto] > -MYREAL_MAX)
                 result += fullparam[tint->fromto];
             break;
         }
@@ -2015,8 +2015,8 @@ probG2 (MYREAL *param, MYREAL *lparam, MYREAL *sm,
     MYREAL result = 0.;
     for (i = 0; i < numpop; i++)
     {
-        if (lparam[i] <= -DBL_MAX)
-            return DBL_MAX;
+        if (lparam[i] <= -MYREAL_MAX)
+            return MYREAL_MAX;
         //      result += p[i] * (LOG2 - lparam[i]);
         for (j = msta[i]; j < me[i]; j++)
         {
@@ -2107,7 +2107,7 @@ print_contribution (nr_fmt * nr, timearchive_fmt ** atl, long G)
         contribution[g] = 0;
     if (nr->world->options->mixplot)
         FPRINTF (mixfile, "\n\n");
-    maxtemp = -DBL_MAX;
+    maxtemp = -MYREAL_MAX;
     for (r = nr->repstart; r < nr->repstop; r++)
     {
         for (g = 0; g < G; g++)
@@ -2172,7 +2172,7 @@ log_param0 (MYREAL *param, MYREAL *lparam, long nn)
         if (param[i] > 0)
             lparam[i] = LOG (param[i]);
         else
-            lparam[i] = -30; //-DBL_MAX;
+            lparam[i] = -30; //-MYREAL_MAX;
     }
 }
 
@@ -2184,7 +2184,7 @@ copies2lcopies (timearchive_fmt * atl)
     if (atl->tl[0].copies > 1)
         atl->tl[0].lcopies = ln_copies (atl->tl[0].copies - 1);
     else
-        atl->tl[0].lcopies = -DBL_MAX;
+        atl->tl[0].lcopies = -MYREAL_MAX;
     for (g = 1; g < atl->T; g++)
     {
         atl->tl[g].lcopies = ln_copies (atl->tl[g].copies);
@@ -2205,7 +2205,7 @@ create_apg0 (MYREAL *apg0, nr_fmt * nr, timearchive_fmt * tyme, long locus)
         else
             copies = tyme->tl[g].copies - 1;
         if (copies == 0)
-            apg0[g] = -DBL_MAX;
+            apg0[g] = -MYREAL_MAX;
         else
         {
 #ifdef LONGSUM
@@ -2299,7 +2299,7 @@ void unset_penalizer_function(boolean inprofiles)
   int msta, msto;
   MYREAL gsum = 0;
   MYREAL ***apg0;
-  MYREAL apgmax = -DBL_MAX;
+  MYREAL apgmax = -MYREAL_MAX;
   //  MYREAL ***apgall = nr->apg;
   MYREAL *apg;
   MYREAL *apg0r;
@@ -2406,7 +2406,7 @@ for (r = nr->repstart; r < nr->repstop; r++)
   ;
    }
  else
-  apg[0] = -DBL_MAX;
+  apg[0] = -MYREAL_MAX;
  if (apgmax < apg[0])
   apgmax = apg[0];
  //other elements
