@@ -25,7 +25,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: combroyden2.c 753 2007-06-15 18:17:57Z beerli $
+$Id: combroyden2.c 886 2007-08-18 03:09:50Z beerli $
  
 -------------------------------------------------------*/
 
@@ -943,7 +943,7 @@ MYREAL golden_section(MYREAL (*fpsi) (MYREAL lamda, helper_fmt * helper, MYREAL
     MYREAL c = 10.;
     MYREAL bl;
     MYREAL d=1.;
-    MYREAL dl = -DBL_MAX;
+    MYREAL dl = -MYREAL_MAX;
     MYREAL ll = 0.;
     helper_fmt helper;
     helper = *thishelper;
@@ -1308,7 +1308,7 @@ maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, MYREAL **hess, lon
   //const MYREAL numbermax = FLT_MAX ;
   //#else
   const MYREAL eps = DBL_EPSILON ;
-  const MYREAL numbermax = DBL_MAX ;
+  const MYREAL numbermax = MYREAL_MAX ;
   //#endif
   boolean stop;
   long repstart, repstop;
@@ -1319,7 +1319,7 @@ maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, MYREAL **hess, lon
   MYREAL lamda;
   long trials;
   MYREAL normd = 1000000;
-  MYREAL normd20 = DBL_MAX;
+  MYREAL normd20 = MYREAL_MAX;
   worldoption_fmt *wopt = world->options;
   long nnn = nr->partsize; // keeps track of profile or standard
   long nn;   // keeps track of the full parameter array
@@ -1393,7 +1393,7 @@ maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, MYREAL **hess, lon
 
     fill_helper (&helper, expxv, xv, world, nr);
     oldL = CALCLIKE (&helper, expxv, xv);
-    //  oldL= -DBL_MAX;
+    //  oldL= -MYREAL_MAX;
     fill_helper (&helper, expxv, xv, world, nr);
     CALCGRADIENT (nr, &helper, gxv);
     memcpy (gxv0, gxv, sizeof (MYREAL) * nnn);
@@ -1407,7 +1407,7 @@ maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, MYREAL **hess, lon
         eventloop ();
 #endif
 
-        newL = -DBL_MAX;
+        newL = -MYREAL_MAX;
    //     if (helper.boolgamma)
     //        lamda = golden_section (psilo, &helper, tempparam, templparam);
         //line_search (dv, gxv, psilo, &helper, oldL, tempparam, templparam);
@@ -1657,7 +1657,7 @@ fill_helper (helper_fmt * helper, MYREAL *param, MYREAL *lparam,
         memcpy (nr->param, param, sizeof (MYREAL) * nr->partsize);
 
     helper->nr = nr;
-    helper->ll = -DBL_MAX;
+    helper->ll = -MYREAL_MAX;
     helper->weight = denom;
     helper->atl = world->atl;
 }
