@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c 1077 2007-12-19 15:30:49Z beerli $
+$Id: data.c 1172 2008-02-19 20:12:21Z beerli $
  
 -------------------------------------------------------*/
 /*! \file data.c
@@ -71,6 +71,8 @@ void read_microalleles (FILE * infile, data_fmt * data, long pop, long ind);
 void read_alleles (FILE * infile, data_fmt * data, long pop, long ind);
 long read_ind_seq (FILE * infile, data_fmt * data, option_fmt * options,
                    long locus, long pop, long ind, long baseread);
+void read_hapmap (FILE * infile, data_fmt * data, option_fmt * options,
+	     long locus, long pop);
 void read_distance_fromfile (FILE * dfile, long tips, long nmlength,
                              MYREAL **m);
 void finish_read_seq (FILE * infile, data_fmt * data, option_fmt * options,
@@ -167,6 +169,10 @@ destroy_data (data_fmt * data)
   myfree(data->numind);
   myfree(data->numalleles);
   myfree(data->seq->sites);
+  if(data->position!=NULL)
+    myfree(data->position);
+  if(data->seq->links!=NULL)
+    myfree(data->seq->links);
   myfree(data->seq);
   myfree(data->geo);
   myfree(data->lgeo);
@@ -195,6 +201,7 @@ destroy_data (data_fmt * data)
 void
 get_data (FILE * infile, data_fmt * data, option_fmt * options)
 {
+  long locus;
     long pop;
     long genomes=1;
     data->hasghost = FALSE;
@@ -204,14 +211,20 @@ get_data (FILE * infile, data_fmt * data, option_fmt * options)
     switch (options->datatype)
     {
     case 's':
-    case 'f':
+    case 'f':// read standard sequence data
         read_sites (data);
         break;
-    case 'n':
+    case 'n': // read snp data
         read_sites (data);
         data->seq->addon = 4;
         break;
-    case 'u':
+    case 'h': //read data from hapmap allele frequency files
+      // there is no sites line in these files!
+      for(locus=0;locus<data->loci;locus++)
+	data->seq->sites[locus] = 1;
+      data->seq->addon = 4;
+        break;
+    case 'u': // read panel snps with unknown panel??????
         read_sites (data);
         data->seq->addon = 4;
         break;
@@ -300,6 +313,8 @@ init_data_structure1 (data_fmt ** data, option_fmt * options)
 	  (*data)->numalleles[pop] =  (*data)->numalleles[0] + pop * loci;
         }
         (*data)->seq->sites = (long *) mycalloc (1, sizeof (long) * loci);
+        (*data)->seq->links = (boolean *) mycalloc (1, sizeof (boolean) * loci);
+        (*data)->position = (long *) mycalloc (1, sizeof (long) * loci);
     }
     else
     {
@@ -442,6 +457,7 @@ void read_header (FILE * infile, data_fmt * data, option_fmt * options)
         break;
     case 's':
     case 'n':
+    case 'h': //hapmap data
     case 'u':
     case 'f':
         sscanf (input, "%1s%ld%ld%[^\n]", &options->datatype, &(data->numpop),
@@ -480,6 +496,7 @@ void read_header (FILE * infile, data_fmt * data, option_fmt * options)
             break;
         case 's':
         case 'n':
+	case 'h': // hapmap data
         case 'u':
         case 'f':
             sscanf (input, "%ld%ld%[^\n]", &(data->numpop), &(data->loci),
@@ -520,60 +537,53 @@ find_delimiter (char *title, char *dlm)
 }
 
 
-/*  old sites reader, will be obsolete once the new is working correctly
-void
-read_sites (data_fmt * data)
-{
-    long locus;
-    char *input, *p, *a;
-    input = (char *) mycalloc (LINESIZE, sizeof (char));
-    FGETS (input, LINESIZE, data->infile);
-    if ((p = (char *) strpbrk (input, CRLF)) != NULL)
-        *p = '\0';
-    p = input;
-    for (locus = 0; locus < data->loci; locus++)
-    {
-        while (isspace ((int) *p))
-            p++;
-        if (locus == 0)
-            a = strtok (p, " ");
-        else
-            a = strtok (NULL, " ");
-        data->seq->sites[locus] = atoi (a);
-        if (data->seq->sites[locus] == 0)
-        {
-            warning ("This does look like sequence data\n");
-            warning ("I just read a number of sites=0\n");
-            warning ("If you use the wrong data type, the program\n");
-            usererror ("will crash anyway, so I stop now\n");
-        }
-    }
-    myfree(input);
-
-}
-*/
 
 //==================================================================
-// read the number of sites for each locus in the dataset
-// does not assume a fixed line length, but assumes that at the end of the line is either
-// a \n or \r or \r\l (similar to the sequence reader) to accommodate windows, mac and
-// unix line ends
+/// read the number of sites for each locus in the dataset,
+/// does not assume a fixed line length, but assumes that at the end of the line is either
+/// a \n or \r or \r\l (similar to the sequence reader) to accommodate windows, mac and
+/// unix line ends.
+/// The generalized sites reader can also read link status using a parethesis notation, and alows to give short names to the
+/// loci, example: ldh=s234 agdh=n3 | gpi=s100 | str1=b1 | str2=m1 a1
+/// the labels a, s, n etc are the same used for the datatype and will mark each locus
+/// for the datatype=h it is assumed that all loci are the same and of type n
+/// plain numbers are considered to be sequence loci with no name
 void
 read_sites (data_fmt * data)
 {
+  boolean linked=TRUE;
     long locus;
     char *input;
-    input = (char *) mycalloc(data->loci * 20 ,sizeof(char));
+    char * word;
+    input = (char *) mycalloc(LONGLINESIZE ,sizeof(char));
+    word = (char *) mycalloc(LONGLINESIZE ,sizeof(char));
     
     for (locus = 0; locus < data->loci-1; locus++)
     {
         read_word(data->infile, input);
-	if(input[0] == '#')
+	switch(input[0])
 	  {
+	  case  '#':
 	    FGETS(input,LINESIZE,data->infile);
 	    locus--;
 	    continue;
+	    break;
+	  case '|':
+	    if(linked==FALSE)
+	      linked=TRUE;
+	    else
+	      linked=FALSE;
+	    break;
+	  default:
+	    if(isalpha(input[0]))
+	      {
+		read_word_delim(input,word,"=");
+	      }
 	  }
+	if(linked)
+	  data->seq->links[locus] = TRUE;
+	else
+	  data->seq->links[locus] = FALSE;
         data->seq->sites[locus] = atoi (input);
         if (data->seq->sites[locus] == 0)
         {
@@ -586,10 +596,14 @@ read_sites (data_fmt * data)
     FGETS(input,LINESIZE,data->infile);
     while(input[0]=='#')
       FGETS(input,LINESIZE,data->infile);
+    if(linked)
+      data->seq->links[locus] = TRUE;
+    else
+      data->seq->links[locus] = FALSE;
     data->seq->sites[locus] = atoi (input);
 
     myfree(input);
-
+    myfree(word);
 }
 
 /*
@@ -778,37 +792,44 @@ read_popdata (FILE * infile, data_fmt * data, long pop, option_fmt * options)
 {
     long ind, baseread = 0;
     long locus = 0;
-    for (ind = 0; ind < data->numind[pop][0]; ind++)
-    {
-        read_indname (infile, data, pop, ind, options->nmlength);
-        switch (options->datatype)
-        {
-        case 'a':
-        case 'b':
-        case 'm':
-            if (data->dlm == '\0')
-                read_alleles (infile, data, pop, ind);
-            else
-                read_microalleles (infile, data, pop, ind);
-            break;
-        case 's':
-        case 'n':
-        case 'u':
-        case 'f':
-            baseread = read_ind_seq (infile, data, options, locus, pop, ind, 0);
-            break;
-        default:
-            usererror
-            ("Wrong datatype, only the types a, m, s, n\n       (electrophoretic alleles, \n       microsatellite data,\n       sequence data,\n       SNP polymorphism)\n        are allowed.\n");
-            break;
-        }
-    }
-    if (!strchr (SEQUENCETYPES, options->datatype))
-        return;
+    if(options->datatype=='h')
+      {
+	read_hapmap(infile, data, options, locus, pop);
+      }
     else
-    {
-        finish_read_seq (infile, data, options, pop, baseread);
-    }
+      {
+	for (ind = 0; ind < data->numind[pop][0]; ind++)
+	  {
+	    read_indname (infile, data, pop, ind, options->nmlength);
+	    switch (options->datatype)
+	      {
+	      case 'a':
+	      case 'b':
+	      case 'm':
+		if (data->dlm == '\0')
+		  read_alleles (infile, data, pop, ind);
+		else
+		  read_microalleles (infile, data, pop, ind);
+		break;
+	      case 's':
+	      case 'n':
+	      case 'u':
+	      case 'f':
+		baseread = read_ind_seq (infile, data, options, locus, pop, ind, 0);
+		break;
+	      default:
+		usererror
+		  ("Wrong datatype, only the types a, m, s, n\n       (electrophoretic alleles, \n       microsatellite data,\n       sequence data,\n       SNP polymorphism)\n        are allowed.\n");
+		break;
+	      }
+	  }
+	if (!strchr (SEQUENCETYPES, options->datatype))
+	  return;
+	else
+	  {
+	    finish_read_seq (infile, data, options, pop, baseread);
+	  }
+      }
 }
 
 void
@@ -909,6 +930,57 @@ read_alleles (FILE * infile, data_fmt * data, long pop, long ind)
     myfree(isave);
 }
 
+void
+read_hapmap (FILE * infile, data_fmt * data, option_fmt * options,
+              long locus, long pop)
+{
+  long ind;
+    char label1;
+    char label2;
+    long label1count;
+    long label2count;
+    long label12count;
+    char *input;
+    input = (char *) mycalloc(LINESIZE,sizeof(char));
+    for(locus=0;locus<data->loci;locus++)
+      {
+	read_word(infile,input);
+	data->position[locus] = atol(input);
+	if(options->printdata)
+	  {
+	    fprintf(stdout,"%20li|",data->position[locus]);
+	  }
+	data->seq->sites[locus]=1;
+	read_word(infile,input);
+	label1 = input[0];;
+	read_word(infile,input);
+	label1count = atol(input);
+	
+	read_word(infile,input);
+	label2 = input[0];
+	read_word(infile,input);
+	label2count = atol(input);
+	read_word(infile,input);
+	label12count = atol(input);
+	if(options->printdata)
+	  {
+	    fprintf(stdout, " freq[%c]=%f freq[%c]=%f\n",label1,
+		    (float) label1count/label12count,label2, (float) label2count/label12count);
+	  }
+	data->numind[pop][locus] = label12count;
+	data->numalleles[pop][locus] = label12count;
+	for(ind=0;ind < label1count; ind++)
+	  {
+	    data->yy[pop][ind][locus][0][0] = label1;
+	  }
+	for(ind=label1count;ind < label12count; ind++)
+	  {
+	    data->yy[pop][ind][locus][0][0] = label2;
+	  }
+      }
+    myfree(input);
+}
+
 long
 read_ind_seq (FILE * infile, data_fmt * data, option_fmt * options,
               long locus, long pop, long ind, long baseread)
@@ -928,6 +1000,7 @@ read_ind_seq (FILE * infile, data_fmt * data, option_fmt * options,
         charstate = getc (infile);
         if (strchr(CRLF,charstate))
         {
+#ifdef INTERLEAVED
             if (options->interleaved)
             {
                 while(strchr(CRLF,charstate=getc(infile)))
@@ -936,6 +1009,7 @@ read_ind_seq (FILE * infile, data_fmt * data, option_fmt * options,
                 return j;
             }
             else
+#endif
                 charstate = ' ';
         }
         if (charstate == ' '
@@ -1153,6 +1227,9 @@ print_data_summary (FILE * file, world_fmt * world, option_fmt * options,
     case 'u':
         strcpy (dstring, "SNP data");
         break;
+    case 'h':
+        strcpy (dstring, "SNP data (Hapmap data)");
+        break;
     default:
         strcpy (dstring, "Unknown data [ERROR]");
         break;
@@ -1249,6 +1326,7 @@ print_data (world_fmt * world, option_fmt * options, data_fmt * data)
             break;
         case 's':
         case 'n':
+	case 'h':
         case 'u':
         case 'f':
             print_seqdata (world, options, data);
@@ -1702,33 +1780,47 @@ read_date_fromfile (FILE * datefile, data_fmt *data, option_fmt *options, long n
     long ind;
     MYREAL oldest = 0. ;
     MYREAL temp;
+    char *name;
+    name = (char *) mycalloc(LINESIZE,sizeof(char));
     if (datefile != NULL)
     {
-        FGETS (input, LINESIZE, datefile); //title line 
+        FGETS (input, LINESIZE, datefile); //title line
+	while(input[0]=='#')
+	  FGETS(input,LINESIZE,datefile);
+ 
 	fprintf(stdout,"\n%i> Tip dates from file %s\n----------------------------------------\n", myID, options->datefilename);	
 	fprintf(stdout,"Generation time:            %f\n", options->generation_year);
 	for(pop=0;pop<data->numpop;pop++)
 	  {
 	    FGETS (input, LINESIZE, datefile); //first populations 
+	    while(input[0]=='#')
+	      FGETS(input,LINESIZE,datefile);
 	    for (locus=0; locus < data->loci; locus++)
 	      {
 		fprintf(stdout,"Mutation rate of Locus %li: %g\n", locus, options->mutationrate_year[locus]);
 		for(ind=0; ind < data->numind[pop][locus]; ind++)
 		  {
 		    FGETS (input, LINESIZE, datefile);
+		    while(input[0]=='#')
+		      FGETS(input,LINESIZE,datefile);
 #ifdef USE_MYREAL_FLOAT
+		    sscanf (input, "%s",name);
 		    sscanf (input+nmlength, "%f",&temp);
 #else
+		    sscanf (input, "%s",name);
 		    sscanf (input+nmlength, "%lf",&temp);
 #endif
 		    fprintf(stdout,"Locus %li: Tipdate %*.*s %f %f\n", locus, (int) nmlength, (int) nmlength, input, temp, temp * options->mutationrate_year[locus] * options->generation_year);
 		    data->sampledates[pop][locus][ind].date = temp;
+		    data->sampledates[pop][locus][ind].name = (char *) mycalloc(strlen(name)+1,sizeof(char));
+		    strcpy(data->sampledates[pop][locus][ind].name, name);
 		    if(oldest < temp)
 		      oldest = temp;
 		  }
 	      }
 	  }
     }
+    free(name);
     return oldest;
 }
 
