@@ -17,16 +17,16 @@
   
 Copyright 2002 Peter Beerli and Joseph Felsenstein
  
-$Id: definitions.h 1090 2007-12-25 20:02:46Z beerli $
+$Id: definitions.h 1156 2008-02-14 18:30:18Z beerli $
  
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "2.3.3"
+#define MIGRATEVERSION "2.4.2"
 #else
 #ifdef SGI
 #undef MIGRATEVERSION
-#define MIGRATEVERSION "2.3"
+#define MIGRATEVERSION "2.4.2"
 #endif
 #endif
 #ifndef MIGRATESUBVERSION
@@ -268,8 +268,8 @@ typedef int boolean;
 #define FIRST 0
 /* the first population is the panel for snps*/
 #define PANEL 0
-#define SEQUENCETYPES "snuf" /*s=sequence,n=linked snp, u=unlinked snp, f=ancestral reconstruction */
-#define SNPTYPES      "nu"
+#define SEQUENCETYPES "snufh" /*s=sequence,n=linked snp, u=unlinked snp, f=ancestral reconstruction h=hapmap snps*/
+#define SNPTYPES      "nuh"
 #define ALLELETYPES   "amb" /*a=infinite allele,m=stepwise, b=brownian */
 
 #define CRLF "\r\n"
