@@ -10,21 +10,27 @@
 #include "sighandler.h"
 
 
-long get_fullbinsum(world_fmt *world, option_fmt *options, long locus)
+long get_fullbinsum(MYREAL *lowerbound, MYREAL *upperbound, world_fmt *world, option_fmt *options, long locus)
 {
   long temp=0;
   long i;
   for(i = 0; i < world->numpop; i++)
     {
       temp += options->bayespriortheta->bins;
+      lowerbound[i] = options->bayespriortheta->min;
+      upperbound[i] = options->bayespriortheta->max;
     }
   for(i = world->numpop; i < world->numpop2; i++)
     {
       temp += options->bayespriorm->bins;
+      lowerbound[i] = options->bayespriorm->min;
+      upperbound[i] = options->bayespriorm->max;
     }
   for(i = world->numpop2; i < world->numpop2+world->bayes->mu * world->loci; i++)
     {
       temp += options->bayespriorrate->bins;
+      lowerbound[i] = options->bayespriorrate->min;
+      upperbound[i] = options->bayespriorrate->max;
     }
   return temp;
 }
@@ -59,6 +65,9 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
   bayeshistogram_fmt *hist;
   long bin;
   MYREAL *delta = bayes->deltahist;
+  //MYREAL *delta; 
+ MYREAL *lowerbound;
+  MYREAL *upperbound;
   //  long binwidth;
   long numbins = 0;
   long numbinsall = 0;
@@ -67,8 +76,15 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 
   done = (boolean *) mycalloc(world->loci, sizeof(boolean));
   params = (MYREAL *) mycalloc(2+ world->numpop2 + world->bayes->mu, sizeof(MYREAL));
-  n = (long *) mycalloc(world->numpop2 + world->bayes->mu, sizeof(long));
-  input = (char *) mycalloc((2+world->numpop2) * 40 , sizeof(char));
+  lowerbound = (MYREAL *) mycalloc(world->numpop2 + world->bayes->mu * world->loci, sizeof(MYREAL));
+  upperbound = (MYREAL *) mycalloc(world->numpop2 + world->bayes->mu * world->loci, sizeof(MYREAL));
+  //delta = (MYREAL *) mycalloc(world->numpop2 + world->bayes->mu * world->loci, sizeof(MYREAL));
+  n = (long *) mycalloc(world->numpop2 + world->bayes->mu * world->loci, sizeof(long));
+#ifdef BFDEBUG
+  input = (char *) mycalloc((2+world->numpop2) * (world->bayes->mu+1) * 40 + (2 + world->options->heated_chains) * 40, sizeof(char));
+#else
+  input = (char *) mycalloc((2+world->numpop2) * (world->bayes->mu+1) * 40 , sizeof(char));
+#endif
   while(FGETS(input,LINESIZE,mdimfile) != EOF)
     {
       // grab the commentlines
@@ -97,8 +113,8 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 
 	      done[locus] = TRUE;
 	      // allocate the number of bins for the histogram
-	      bayes->histogram[locus].binsum = get_fullbinsum(world, options, locus);
-	      bayes->histogram[locus].results = (MYREAL *) mycalloc(bayes->histogram[locus].binsum, sizeof(MYREAL));
+	      bayes->histogram[locus].binsum = get_fullbinsum(lowerbound, upperbound, world, options, locus);
+	      bayes->histogram[locus].results = (MYREAL *) mycalloc(bayes->histogram[locus].binsum + 1, sizeof(MYREAL));
 	      bayes->histogram[locus].set95 = (char *) mycalloc(bayes->histogram[locus].binsum* 2 + 2, sizeof(char));
 	      bayes->histogram[locus].set50 = world->bayes->histogram[locus].set95 + bayes->histogram[locus].binsum + 1;
 	      memset(world->bayes->histogram[locus].results, 0 , sizeof(MYREAL) * (world->bayes->histogram[locus].binsum)); 
@@ -130,12 +146,14 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 	      numbins = numbinsall - hist->bins[j];
 
 	      //binwidth = hist->bins[j];
-	      bin = (long) (params[j+2] / delta[j]);
-	      m = bin * delta[j];
-	      if(m < hist->minima[j0])
-		hist->minima[j0] = m;
-	      if(m > hist->maxima[j0])
-		hist->maxima[j0] = m;
+	      bin = (long) ((params[j+2]-lowerbound[j]) / delta[j]);
+	      hist->minima[j0] = lowerbound[j];
+	      hist->maxima[j0] = upperbound[j];
+	      //	      m = bin * delta[j];
+	      //if(m < hist->minima[j0])
+	      //	hist->minima[j0] = m;
+	      //if(m > hist->maxima[j0])
+	      //		hist->maxima[j0] = m;
 	      hist->results[numbins + bin] += 1.;
 	    }
 	  if(bayes->mu)
@@ -143,18 +161,21 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 	      //binwidth = hist->bins[j0];
 	      numbins = numbinsall;
 	      params[j0+2] = atof(strsep(&inptr,"\t"));
-	      bin = (long) (params[j0+2] / delta[j0]); 
-	      m = bin * delta[j0];
-	      if(m < hist->minima[j0])
-		hist->minima[j0] = m;
-	      if(m > hist->maxima[j0])
-		hist->maxima[j0] = m;
-
+	      n[j0] += 1;
+	      hist->means[j0] += (params[j0+2] - hist->means[j0]) / n[j0];
+	      bin = (long) ((params[j0+2]-lowerbound[j0]) / delta[j0]); 
+	      //m = bin * delta[j0];
+	      //if(m < hist->minima[j0])
+	      //	hist->minima[j0] = m;
+	      //if(m > hist->maxima[j0])
+	      //		hist->maxima[j0] = m;
 	      hist->results[numbins + bin] += 1.;
 	    }
 	}
     } 
   myfree(params);
+  myfree(lowerbound);
+  myfree(upperbound);
   myfree(n);
   myfree(done);
   myfree(input);
