@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 1121 2008-01-14 14:00:46Z beerli $*/
+/* $Id: main.c 1160 2008-02-16 15:41:22Z beerli $*/
 
 #include "migration.h"
 #include "sighandler.h"
@@ -226,6 +226,13 @@ prepare_next_chain (world_fmt ** universe, worldoption_fmt * options,
                     long *pluschain, long locus, long replicate);
 
 void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options);
+
+#ifdef MPI /* */
+void      print_marginal_like(float *temp, long *z, world_fmt * world);
+#else /*not MPI*/
+void      print_marginal_like(char *temp, long *c, world_fmt * world);
+#endif
+
 void print_burnin_stop(FILE *file, world_fmt **universe, option_fmt * options);
 void
 print_heating_progress (world_fmt ** universe,
@@ -323,6 +330,9 @@ main (int argc, char **argv)
     //if(myID==0)
     //  c=fgetc(stdin);
     //MYMPIBARRIER (comm_world);
+
+    //does not work?    set_memory_limit(5,50);
+
 #ifdef SLOWNET
     // slow network parallel version
     profiledone = 0;
@@ -586,16 +596,16 @@ main (int argc, char **argv)
             mpi_send_stop (EARTH);
         }
 #ifndef INTEGRATEDLIKE    
-        if (!options->bayes_infer)
-	  {
+	//        if (!options->bayes_infer)
+	//  {
 #endif
-	    if (EARTH->options->lratio->counter > 0)
-	      print_lratio_test (EARTH, &Gmax);
-	    if (options->aic)
-	      akaike_information (EARTH, &Gmax);
-	    profile_tables (options, EARTH, &Gmax);
+	//   if (EARTH->options->lratio->counter > 0)
+	//      print_lratio_test (EARTH, &Gmax);
+	//    if (options->aic)
+	//      akaike_information (EARTH, &Gmax);
+	//    profile_tables (options, EARTH, &Gmax);
 #ifndef INTEGRATEDLIKE    
-	  }
+	//  }
 #endif
 #else  /* SLOWNET*/
 
@@ -699,12 +709,12 @@ main (int argc, char **argv)
         MYMPIBARRIER (comm_world);
         MPI_Finalize ();
 #endif /*MPI*/
-	myfree(seed);
-	myfree(newseed);
-	myfree(generator);
-	free_universe(universe, usize, options);
-	destroy_data(data);
-	destroy_options(options);
+	//	myfree(seed);
+	//myfree(newseed);
+	//myfree(generator);
+	//free_universe(universe, usize, options);
+	//destroy_data(data);
+	//destroy_options(options);
 	// for debugging with MallocDebug on macosx
 	#ifdef MACMALLOCDEBUG
 	while(TRUE)
@@ -2023,8 +2033,14 @@ run_steps (world_fmt ** universe,
     MYREAL var=0.0;
     if(EARTH->cold && EARTH->options->bayes_infer)
       single_chain_var (NULL, step, &var, NULL, NULL);
+#ifdef MPI
+    // does not work? check_memory_limit();
+#endif
     for (step = 0; step < steps + 1; step++)
     {
+#ifdef MPI
+      // does not work?? check_memory_limit();
+#endif
         EARTH->increment = increment;
         run_increments (universe, usize, options, localheating_pool,
                         increment, step, steps);
@@ -2466,6 +2482,76 @@ void calculate_BF(world_fmt **universe, option_fmt *options)
     }
 }
 
+#ifdef BFDEBUG
+void  print_marginal_order(FILE *file, world_fmt *world)
+{
+  long i;
+
+  for(i=0;i<world->options->heated_chains;i++)
+    fprintf(file,"# --  %s = %f\n", "Thermodynamic temperature", world->options->heat[i]);
+    fprintf(file,"# --  %s\n", "Marginal log(likelihood) [Thermodynamic integration]");
+    fprintf(file,"# --  %s\n", "Marginal log(likelihood) [Harmonic mean]");
+}
+
+#ifdef MPI /* */
+void      print_marginal_like(float *temp, long *z, world_fmt * world)
+{
+  long locus = world->locus;
+  long t;
+  long hc = world->options->heated_chains; 
+  MYREAL lsum; 
+  MYREAL heat0, heat1;
+
+  if(world->options->heating)
+    {
+      lsum = 0.;
+      for(t=1; t < hc; t++)
+	{
+	  heat0 = 1./world->options->heat[t-1] ;
+	  heat1 = 1./world->options->heat[t];
+	  // this ignores adaptive heating for MPI!!!!
+	  temp[*z] = (float) world->bf[locus * hc + t-1];
+	  *z += 1;
+	  lsum += (heat0 - heat1) * ((world->bf[locus * hc + t-1] + world->bf[locus * hc + t]) * 0.5);
+	}
+      temp[(*z)++] =  (float) world->bf[locus * hc + t-1];
+      temp[(*z)++] =  (float) lsum;
+    }
+  temp[(*z)++] =  (float) world->hmscale[locus] - log(world->hm[locus]);
+}
+#else /*not MPI*/
+void      print_marginal_like(char *temp, long *c, world_fmt * world)
+{
+  long locus = world->locus;
+  long t;
+  long hc = world->options->heated_chains;  
+  MYREAL lsum;
+  MYREAL heat0, heat1;
+  if(world->options->heating)
+    {
+      lsum = 0.;
+      for(t=1; t < hc; t++)
+	{
+	  if(world->options->adaptiveheat)
+	    {
+	      heat0 = world->options->averageheat[t-1] ;
+	      heat1 = world->options->averageheat[t];
+	    }
+	  else
+	    {
+	      heat0 = 1./ world->options->heat[t-1] ;
+	      heat1 = 1./ world->options->heat[t];
+	    }
+	  *c += sprintf(temp+ *c,"\t%f", world->bf[locus * hc + t-1]);
+	  lsum += (heat0 - heat1) * ((world->bf[locus * hc + t-1] + world->bf[locus * hc + t]) * 0.5);
+	}
+      *c += sprintf(temp + *c,"\t%f", world->bf[locus * hc + t-1]);
+      *c += sprintf(temp + *c,"\t%f", lsum);
+    }
+  *c += sprintf(temp + *c,"\t%f", world->hmscale[locus] - log(world->hm[locus]));
+}
+#endif /*not MPI*/
+#endif /*BFDEBUG*/
 
 #ifdef LONGSUM
 /// put timepoints into the total tree to allow for bottlenecks and growth 
