@@ -18,7 +18,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: mcmc1.c 1068 2007-12-14 19:10:22Z beerli $
+$Id: mcmc1.c 1140 2008-01-30 04:19:42Z beerli $
 -------------------------------------------------------*/
 /* \file mcmc1.c
 
@@ -128,6 +128,7 @@ tree_update (world_fmt * world, long g)
 #ifdef TESTING2
     static boolean have_proposal=FALSE;
 #endif
+    short show=0;
     boolean coalesced;
     //  boolean test;
     char event;
@@ -198,7 +199,7 @@ tree_update (world_fmt * world, long g)
       main loop: sliding down the tree  */
     slider = 0;
 #ifdef TESTINGDATE
-    //    printf("Time    Pop Type Lineages\n");
+    //    printf("\nTime    Pop Type Lineages [mutrate=%f]\n",proposal->world->options->mu_rates[world->locus]);
 #endif
     while (nexttime <= endtime)
       {
@@ -208,10 +209,14 @@ tree_update (world_fmt * world, long g)
 				     1].from : proposal->origin->pop;
         proposal->time = age + eventtime (proposal, actualpop, tentry, &event);
 #ifdef TESTINGDATE
-	// printf("%0.5f  %3li  %c  %3li",proposal->time,actualpop,event,tentry->lineages[0]);
-	//for(long jj = 1;jj < proposal->world->numpop; jj++)
-	//printf(" %3li",tentry->lineages[jj]);
+	//	if(show==1)
+	//  {
+	//	 printf("%0.5f  %3li  %c  %3li",proposal->time,actualpop,event,tentry->lineages[0]);
+	//long jj;
+	//for(jj = 1;jj < proposal->world->numpop; jj++)
+	//  printf(" %3li",tentry->lineages[jj]);
 	//printf("\n");
+	//}
 #endif
         //      FPRINTF(stderr,"age=%f event=%c\n",proposal->time,event);
         if (proposal->time < nexttime)
@@ -251,6 +256,10 @@ tree_update (world_fmt * world, long g)
         }   /*end if proposal->time < nextime */
         age = nexttime;
         tentry = &(*timevector).tl[(tentry->slice) + 1]; /*next entry in timelist */
+	if((tentry->slice+1) >= timevector->T)
+	  {
+	    break;
+	  }
         nexttime = tentry->age;
     }
     if (!coalesced)
