@@ -9,12 +9,12 @@
  
  presents the menu and its submenus.                                                                                                               
  Peter Beerli 1996, Seattle
- beerli@csit.fsu.edu
+ beerli@scs.fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: menu.h 215 2006-01-03 00:03:51Z beerli $
+$Id: menu.h 514 2006-11-09 20:14:08Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -24,4 +24,5 @@ extern void print_menu_accratio (long a, long b, world_fmt *world);
 extern long print_title (world_fmt * world, option_fmt * options);
 extern void get_menu (option_fmt * options);
 extern char * is_priortype(int priorset);
+extern char * is_proposaltype(boolean proposalset);
 #endif /*MENU_INCLUDE */
