@@ -16,7 +16,7 @@
  
   Copyright 2002 Peter Beerli and Joseph Felsenstein, Seattle WA
   Copyright 2003 Peter Beerli, Tallahassee FL
-  $Id: migration.h 1052 2007-12-03 03:44:31Z beerli $
+  $Id: migration.h 1156 2008-02-14 18:30:18Z beerli $
   *----------------------------------------------------------------
 */
 /**
@@ -58,6 +58,7 @@ typedef struct tipdate_fmt
 {
   MYREAL date;
   long   id;
+  char * name;
 } 
 tipdate_fmt;
 
@@ -129,25 +130,26 @@ typedef struct seqmodel_fmt
     FloatVec freq_trans;
 #endif
     
-    MYREAL freqa, freqt, freqg, freqc;      //!< base frequencies
-    MYREAL freqr, freqy;                    //!< frequency of purins
-    MYREAL freqar, freqcy, freqgr, freqty;  //!< frequency of transitions
-    MYREAL aa, bb;                          //
-    long oldsite;                           //!< number of site patterns (raw, with SNP adjustment
-    long endsite;                           //!< number of site patterns 
-    MYREAL xi;                              //!< ratio of transitions
-    MYREAL xv;                              //!< ratio of transversions
-    MYREAL ttratio;                         //!< ration between transitions and transversions
-    MYREAL fracchange;                      //
-    long *sites;                            //
-    long *alias;                            //
-    long *ally;                             //
-    long *category;                         //
-    short *weight;                          //
-    long weightsum;                         //
-    long *aliasweight;                      //
-    long *location;                         //
-    long addon;                             //
+  MYREAL freqa, freqt, freqg, freqc;      //!< base frequencies
+  MYREAL freqr, freqy;                    //!< frequency of purins
+  MYREAL freqar, freqcy, freqgr, freqty;  //!< frequency of transitions
+  MYREAL aa, bb;                          //
+  long oldsite;                           //!< number of site patterns (raw, with SNP adjustment
+  long endsite;                           //!< number of site patterns 
+  MYREAL xi;                              //!< ratio of transitions
+  MYREAL xv;                              //!< ratio of transversions
+  MYREAL ttratio;                         //!< ration between transitions and transversions
+  MYREAL fracchange;                      //
+  long *sites;                            //
+  long *alias;                            //
+  long *ally;                             //
+  long *category;                         //
+  short *weight;                          //
+  long weightsum;                         //
+  long *aliasweight;                      //
+  long *location;                         //
+  long addon;                             //
+  boolean *links;                         //!< information about link status of locus
 }
 seqmodel_fmt;
 
@@ -185,6 +187,7 @@ typedef struct _data
     char ***indnames;       //!< array of individual names per population
     long numpop;            //!< number of populations
     long loci;              //!< number of loci
+  long *position;           //!< position on chromosome [what to do with mutiple chromosomes?]
     seqmodel_fmt *seq;      //!< sequence data model    
     MYREAL freq;            //
     MYREAL freqlast;        //
@@ -719,6 +722,8 @@ typedef struct _worldoption
     MYREAL *lmu_rates;
   MYREAL *meanmu;
   MYREAL *inheritance_scalars;
+  MYREAL *heat;
+  MYREAL *averageheat;
 #ifdef LONGSUM
 
     boolean fluctuate;
