@@ -14,7 +14,7 @@
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: sequence.h 701 2007-05-08 01:57:47Z beerli $
+$Id: sequence.h 786 2007-07-21 05:55:24Z beerli $
 -------------------------------------------------------*/
 
 extern void initratio (option_fmt * options);
@@ -39,8 +39,7 @@ extern void print_seqfreqs (FILE * outfile, world_fmt * world,
 			    option_fmt * options);
 extern MYREAL treelike_seq (world_fmt * world, long locus);
 extern MYREAL treelike_snp (world_fmt * world, long locus);
-extern void snp_invariants (contribarr invariants, long endsite, long rcategs,
-			    seqmodel_fmt * seq, phenotype x1);
+extern void snp_invariants (contribarr invariants, world_fmt *world, long locus,  phenotype x1);
 extern void make_sequences (world_fmt * world, option_fmt * options,
 			    data_fmt * data, long locus);
 extern void make_invarsites (world_fmt * world, data_fmt * data, long locus);
