@@ -579,8 +579,8 @@ void print_expected_values_title(FILE *file, boolean progress)
 
 void print_expected_values(world_fmt * world)
 {
-  //  long locus;
-  //  long sumloc = (world->loci > 1) ? 1 : 0;
+  long locus;
+  long sumloc = (world->loci > 1) ? 1 : 0;
   if(world->options->skyline)
     {
       // prepare skyline histogram for printing
@@ -593,16 +593,16 @@ void print_expected_values(world_fmt * world)
       // print title to ascii-outfile
       print_expected_values_title(world->outfile, TRUE);
       // print content to stdout and to ascii - outfile
-      //for(locus=0; locus < world->loci+sumloc; locus++)
-      //	{
-	  //	  if(world->options->progress)
-	    // print_expected_values_list(stdout, locus, world->mighistloci[locus].eventbins, 
-	    //			       world->mighistloci[locus].eventbinsize, 
-	    //			       world->mighistloci[locus].eventbinnum, world->numpop);
-	    //print_expected_values_list(world->outfile, locus, world->mighistloci[locus].eventbins, 
-	    //			     world->mighistloci[locus].eventbinsize, 
-	    //			     world->mighistloci[locus].eventbinnum, world->numpop);
-      //}
+      for(locus=0; locus < world->loci+sumloc; locus++)
+      	{
+	  	  if(world->options->progress)
+	     print_expected_values_list(stdout, locus, world->mighistloci[locus].eventbins, 
+	    			       world->mighistloci[locus].eventbinsize, 
+	    			       world->mighistloci[locus].eventbinnum, world->numpop);
+	    print_expected_values_list(world->outfile, locus, world->mighistloci[locus].eventbins, 
+	    			     world->mighistloci[locus].eventbinsize, 
+	    			     world->mighistloci[locus].eventbinnum, world->numpop);
+      }
 #ifdef PRETTY
 	  pdf_skyline_histogram(world->loci, world->numpop2,  world, FALSE);
 	  if(world->options->bayes_infer)
