@@ -63,20 +63,24 @@ void set_slice_param(MYREAL newparam, long which, world_fmt * world)
 {
   MYREAL oldparam;
   long numpop2 = world->numpop2;  
-  // set new parameters and allow for custom migration matrix
+ 
+  if(newparam < world->bayes->minparam[which])
+    newparam = world->bayes->minparam[which];
+  if(newparam > world->bayes->maxparam[which])
+    newparam = world->bayes->maxparam[which];
+  
   if(which<numpop2)
     {
-      if(newparam<0)
-	newparam = world->bayes->minparam[which];
       bayes_set_param(world->param0,newparam,which,world->options->custm2, world->numpop);
       reprecalc_world(world, which);
-      }
-    else
-      {
-	oldparam = world->options->mu_rates[world->locus];
-	world->options->mu_rates[world->locus] = newparam;
-	recalc_timelist(world, world->options->mu_rates[world->locus] / oldparam);
-      }
+    }
+  else
+    {
+      oldparam = world->options->mu_rates[world->locus];
+      world->options->mu_rates[world->locus] = newparam;
+      //printf("@@@ rate = %f\n",newparam);
+      recalc_timelist(world, world->options->mu_rates[world->locus] , oldparam);
+    }
 }
 
 
@@ -91,7 +95,7 @@ void set_multi_slice_param(MYREAL *newparam, long numparam, world_fmt * world)
     {
 	oldparam = world->options->mu_rates[world->locus];
 	world->options->mu_rates[world->locus] = newparam[numpop2];
-	recalc_timelist(world, world->options->mu_rates[world->locus] / oldparam);
+	recalc_timelist(world, world->options->mu_rates[world->locus] , oldparam);
     }
 }
 
