@@ -11,29 +11,48 @@
  * comparison between characters
  * used in qsort()
  */
-int charcmp (const void *v1, const void *v2);
+extern int charcmp (const void *v1, const void *v2);
 
 /*-------------------------------------------
  * comparison between strings
  * used in qsort()
  */
-int stringcmp (const void *v1, const void *v2);
+extern int stringcmp (const void *v1, const void *v2);
 
 
 /*-------------------------------------------
- * comparison between numbers (doubles,longs,
+ * comparison between numbers (doubles, floats, longs,
  *  and ints) used in qsort()
  */
-int numcmp (const void *v1, const void *v2);
-int longcmp (const void *v1, const void *v2);
-int intcmp (const void *v1, const void *v2);
+extern int numcmp (const void *v1, const void *v2);
+extern int floatcmp (const void *v1, const void *v2);
+extern int longcmp (const void *v1, const void *v2);
+extern int intcmp (const void *v1, const void *v2);
+
+
+/*-------------------------------------------
+* comparison between pairs of doubles
+* used in qsort()
+* -- using the second value for comparison
+*/
+extern int
+paircmp (const void *v1, const void *v2);
+/* --using the first value for comparison */
+extern int
+paircmp_first (const void *v1, const void *v2);
+
+/*-------------------------------------------
+ * sort first the second element and then sort
+ * those elements that are the same using the first element
+ */
+extern void  paired_qsort2(pair *x, long xelem);
 
 /*-------------------------------------------
  * comparison between the times in the
  * the timevector (vtlist) and a given time
  * used in qsort()
  */
-int agecmp (const void *x, const void *y);
+extern int agecmp (const void *x, const void *y);
 
 /*-------------------------------------------
  * comparison in nodep->v 
@@ -42,14 +61,14 @@ int agecmp (const void *x, const void *y);
  * to the end of nodelist.
  * used in qsort()
  */
-int delcmp (const void *x, const void *y);
+extern int delcmp (const void *x, const void *y);
 
 
 /*------------------------------------------
  * compares migr_table time entries
  * used in qsort of the migr_table
  */
-int migr_time_cmp (const void *x, const void *y);
+extern int migr_time_cmp (const void *x, const void *y);
 
 
 /*-------------------------------------------
@@ -57,7 +76,7 @@ int migr_time_cmp (const void *x, const void *y);
  * the timevector (vtlist) and a given time
  * used in bsearch()
  */
-int searchagecmp (const void *x, const void *y);
+extern int searchagecmp (const void *x, const void *y);
 
 
 /*-------------------------------------------
