@@ -11,12 +11,12 @@
  from the AMS library
  
  Peter Beerli 1999, Seattle
- beerli@csit.fsu.edu
+ beerli@scs.fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: spline.h 175 2005-12-02 14:51:23Z beerli $
+$Id: spline.h 514 2006-11-09 20:14:08Z beerli $
 -------------------------------------------------------*/
 
 extern int dbvssc_ (MYREAL *x, MYREAL *y, long *np, long *n, long *k,
