@@ -20,7 +20,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c 1090 2007-12-25 20:02:46Z beerli $
+$Id: tools.c 1172 2008-02-19 20:12:21Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 
@@ -483,7 +483,9 @@ void collect_nodelet(world_fmt *world, node *p)
     }
   else
     {
+#ifdef DEBUG
       warning("in node collection phase we should not need to allocate new space\n");
+#endif
       oldalloc = world->node_collection_allocated;
       world->node_collection_allocated += 400;
       world->node_collection = (node **) realloc(world->node_collection, world->node_collection_allocated * sizeof(node*));
@@ -932,6 +934,25 @@ void remove_trailing_blanks(char **filename)
   (*filename)[pos] = '\0';   
 }
 
+///
+/// read a single word from a string up to the position of 
+/// the breakchar and return that position 
+long read_word_delim(char *input, char *word, char * delim)
+{
+  long i = 1;
+    int ch;
+    long count = 0;
+    ch = input[0];
+    while (isspace (ch))
+        ch = input[i++];
+    while(strchr(delim, ch)==NULL)
+    {
+        word[count++] = ch;
+        ch = input[i++];
+    }
+    word[count]='\0';
+    return i;
+}
 ///
 /// read a single word from a file
 /// words are delimited by withespace 
