@@ -14,7 +14,7 @@
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: tree.h 633 2007-03-06 04:14:07Z beerli $
+$Id: tree.h 1052 2007-12-03 03:44:31Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -23,7 +23,7 @@ extern void buildtree (world_fmt * world, option_fmt * options,
                            data_fmt * data, long locus);
 extern void create_treetimelist (world_fmt * world, timelist_fmt ** ltl,
                                      long locus);
-extern void allocate_lineages (timelist_fmt **timevector, vtlist * tl, long allocT, long offset, long numpop);
+extern void allocate_lineages (timelist_fmt **timevector,  long offset, long numpop);
 extern void fix_times (world_fmt * world, option_fmt * options);
 extern void first_smooth (world_fmt * world, long locus);
 extern void set_dirty (node * p);
@@ -48,12 +48,13 @@ extern void     allocate_xseq(xarray_fmt *x, long sites, long categs);
 extern void     zero_xseq(xarray_fmt *x, long sites, long categs);
 extern void copy_tree (world_fmt * original, world_fmt * kopie);
 extern void swap_tree (world_fmt * tthis, world_fmt * that);
-
+void free_nodelet (node * p, long num, world_fmt * world);
+extern void free_mignodelet (node * p, world_fmt * world);
 extern void calc_treelength (node * p, MYREAL *treelen);
 extern MYREAL calc_pseudotreelength (proposal_fmt * proposal, MYREAL treelen);
 extern void swap (void *a, void *b);
 extern void free_treetimes (world_fmt * world, long size);
 extern void free_tree (node * p, world_fmt * world);
 extern long number_genomes (int datatype);
-
+extern node *add_migration (world_fmt *world, node * p, long from, long to, MYREAL utime);
 #endif /*TREE_INCLUDE */
